@@ -1,4 +1,5 @@
 use dinero::{parser::Tokenizer, CommonOpts};
+use structopt::StructOpt;
 
 #[test]
 #[should_panic(expected = "Should be money.")]
@@ -14,12 +15,12 @@ fn not_money() {
 "
         .to_string(),
     );
-    let parsed = tokenizer.tokenize(&CommonOpts::new());
+    let parsed = tokenizer.tokenize(&CommonOpts::from_iter(["", "-f", ""].iter()));
 
     // It parses -- it has not panicked
     assert!(true);
 
     // But to a wrong ledger -- panics!
-    let _ledger = parsed.to_ledger(&CommonOpts::new());
+    let _ledger = parsed.to_ledger(&CommonOpts::from_iter(["", "-f", ""].iter()));
     unreachable!("This has panicked")
 }
